/**
 * Copyright (c) 2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.jbi.messaging.exchange.impl;

import java.util.logging.Logger;

import javax.jbi.messaging.MessageExchangeFactory;
import javax.jbi.servicedesc.ServiceEndpoint;
import javax.xml.namespace.QName;

import org.ow2.petals.commons.Constants;
import org.ow2.petals.jbi.messaging.exchange.AbstractMessageExchangeFactory;
import org.ow2.petals.jbi.messaging.exchange.PetalsMessageExchange;

import com.ebmwebsourcing.easycommons.uuid.QualifiedUUIDGenerator;

/**
 * A default implementation for the {@link MessageExchangeFactory} with factory methods to create instances of
 * {@link AbstractMessageExchangeFactory}.
 * 
 * @author vnoel
 *
 */
public class DefaultMessageExchangeFactory extends AbstractMessageExchangeFactory {

    protected static final QualifiedUUIDGenerator petalsQualifiedUUIDGenerator = new QualifiedUUIDGenerator(
            Constants.UUID_DOMAIN);

    protected DefaultMessageExchangeFactory(final ServiceEndpoint consumerEndpoint,
            final ServiceEndpoint targetEndpoint, final QName targetInterface, final QName targetService,
            final Logger logger) {
        super(consumerEndpoint, targetEndpoint, targetInterface, targetService, logger);
    }

    @Override
    protected PetalsMessageExchange buildExchange() {
        return new MessageExchangeImpl(petalsQualifiedUUIDGenerator.getNewID());
    }

    public static MessageExchangeFactory create(final ServiceEndpoint consumerEndpoint, final Logger logger) {
        return new DefaultMessageExchangeFactory(consumerEndpoint, null, null, null, logger);
    }

    public static MessageExchangeFactory createForEndpoint(final ServiceEndpoint consumerEndpoint,
            final Logger logger, final ServiceEndpoint targetEndpoint) {
        return new DefaultMessageExchangeFactory(consumerEndpoint, targetEndpoint, null, null, logger);
    }

    public static MessageExchangeFactory createForInterface(final ServiceEndpoint consumerEndpoint,
            final Logger logger, final QName targetInterface) {
        return new DefaultMessageExchangeFactory(consumerEndpoint, null, targetInterface, null, logger);
    }

    public static MessageExchangeFactory createForService(final ServiceEndpoint consumerEndpoint,
            final Logger logger, final QName targetService) {
        return new DefaultMessageExchangeFactory(consumerEndpoint, null, null, targetService, logger);
    }
}
